@@ -76,6 +76,7 @@ bool InvidiousApi::supportsFeature(AbstractApi::SupportedFeature feature)
     switch (feature) {
     case PopularPage:
     case TrendingCategories:
+    case SponsorBlock:
         return true;
     }
 
@@ -99,7 +100,7 @@ QFuture<LogInResult> InvidiousApi::logIn(const QString &username, const QString
     request.setHeader(QNetworkRequest::ContentTypeHeader, QByteArrayLiteral("application/x-www-form-urlencoded"));
     request.setAttribute(QNetworkRequest::RedirectPolicyAttribute, QNetworkRequest::RedirectPolicy::ManualRedirectPolicy);
 
-    return post<LogInResult>(std::move(request), params.toString().toUtf8(), [=](QNetworkReply *reply) -> LogInResult {
+    return post<LogInResult>(std::move(request), params.toString().toUtf8(), [this](QNetworkReply *reply) -> LogInResult {
         const auto cookies = reply->header(QNetworkRequest::SetCookieHeader).value<QList<QNetworkCookie>>();
 
         if (!cookies.isEmpty()) {
@@ -121,11 +122,6 @@ QFuture<VideoResult> InvidiousApi::requestVideo(const QString &videoId)
     });
 }
 
-QString InvidiousApi::resolveVideoUrl(const QString &videoId)
-{
-    return QStringLiteral("ytdl://%1").arg(videoId);
-}
-
 QFuture<SearchListResult> InvidiousApi::requestSearchResults(const SearchParameters &parameters, Paginator *paginator)
 {
     QHash<QString, QString> searchParameters = parameters.toQueryParameters();
@@ -397,7 +393,7 @@ QFuture<Result> InvidiousApi::removeVideoFromPlaylist(const QString &plid, const
 
 Error InvidiousApi::invalidJsonError()
 {
-    return std::pair(QNetworkReply::InternalServerError, i18n("Server returned no valid JSON."));
+    return {QNetworkReply::InternalServerError, i18n("Server returned no valid JSON.")};
 }
 
 Result InvidiousApi::checkIsReplyOk(QNetworkReply *reply)
