@@ -3,8 +3,10 @@
 
 #pragma once
 
+#include "paginator.h"
 #include "preferences.h"
 #include "sourceconfig.h"
+#include "subscriptionlistmodel.h"
 
 #include <QDir>
 #include <QObject>
@@ -24,6 +26,7 @@ class VideoSource : public QObject
     Q_PROPERTY(QString url READ url WRITE setUrl NOTIFY urlChanged)
     Q_PROPERTY(Type type READ type WRITE setType NOTIFY typeChanged)
     Q_PROPERTY(bool loggedIn READ loggedIn NOTIFY credentialsChanged)
+    Q_PROPERTY(bool canLogIn READ canLogIn NOTIFY canLogInChanged)
     Q_PROPERTY(QString username READ username NOTIFY usernameChanged)
     Q_PROPERTY(QInvidious::Preferences preferences READ preferences WRITE setPreferences NOTIFY preferencesChanged)
 
@@ -42,14 +45,13 @@ public:
     void setType(Type type);
 
     bool loggedIn() const;
+    bool canLogIn() const;
+    Q_INVOKABLE void prepareLogIn();
     Q_INVOKABLE void logOut();
 
     void setUsername(const QString &username);
     QString username() const;
 
-    void setCookie(const QString &cookie);
-    QString cookie() const;
-
     QInvidious::Preferences preferences();
     void setPreferences(const QInvidious::Preferences &preferences);
 
@@ -68,6 +70,20 @@ public:
     Q_INVOKABLE bool supportsPopularPage() const;
     Q_INVOKABLE bool supportsTrendingCategories() const;
 
+    std::optional<QList<QString>> &subscriptions();
+
+    // TODO: support PeerTube JSON (see https://github.com/Chocobozzz/PeerTube/pull/6215)
+    /**
+     * Imports subscriptions from @p filePath.
+     */
+    Q_INVOKABLE void importSubscriptions(const QString &filePath);
+
+    // TODO: we should really not attach this to the model, if we want to move the import/export button somewhere else later.
+    /**
+     * Exports subscriptions to @p filePath. Requires @p model to reuse the channel data.
+     */
+    Q_INVOKABLE void exportSubscriptions(SubscriptionListModel *model, const QString &filePath);
+
 Q_SIGNALS:
     void urlChanged();
     void typeChanged();
@@ -76,25 +92,25 @@ Q_SIGNALS:
     void preferencesChanged();
     void finishedLoading();
     void subscriptionsChanged();
+    void canLogInChanged();
+    void importExportCompleted(int numSubscriptions);
+    void importExportError(const QString &reason);
 
 private:
     friend class SubscriptionController;
 
     void createApi();
-    void setApiCookie();
-    QString cookieKey();
     void fetchPreferences();
     void fetchSubscriptions();
-    void fetchHistory(qint32 page = 1);
+    void fetchHistory();
     void setSubscriptions(const QList<QString> &subscriptions);
-    std::optional<QList<QString>> &subscriptions();
 
     SourceConfig m_config;
     QString m_key;
     QInvidious::AbstractApi *m_api = nullptr;
-    QString m_cookie;
     QInvidious::Preferences m_preferences;
     std::optional<QList<QString>> m_subscriptions;
     QList<QString> m_watchedVideos;
     bool m_finishedLoading = false;
+    QInvidious::Paginator m_historyPagination;
 };
